@@ -3,6 +3,7 @@ use std::convert::TryInto;
 use std::slice::Iter;
 
 use ross_config::config::Config;
+use ross_config::creator::Creator;
 use ross_config::event_processor::EventProcessor;
 use ross_config::extractor::*;
 use ross_config::filter::state::*;
@@ -109,9 +110,9 @@ impl Parser {
 
         while let Some(token) = token_iterator.next() {
             match token {
-                Token::Keyword(KeywordToken::Store) => {
+                Token::Keyword(KeywordToken::Let) => {
                     let mut state_name = String::new();
-                    let state = Self::parse_store_statement(&mut token_iterator, &mut state_name)?;
+                    let state = Self::parse_let_statement(&mut token_iterator, &mut state_name)?;
 
                     let mut state_index = 0;
 
@@ -125,20 +126,21 @@ impl Parser {
                     {
                         return Err(ParserError::DuplicateVariable);
                     }
-                },
+                }
                 Token::Keyword(KeywordToken::Const) => {
                     let mut variable_name = String::new();
-                    let variable = Self::parse_const_statement(&mut token_iterator, &mut variable_name)?;
+                    let variable =
+                        Self::parse_const_statement(&mut token_iterator, &mut variable_name)?;
 
-                    if let Some(_) = variable_map.insert(variable_name, variable)
-                    {
+                    if let Some(_) = variable_map.insert(variable_name, variable) {
                         return Err(ParserError::DuplicateVariable);
                     }
-                },
+                }
                 Token::Keyword(KeywordToken::Send) => {
-                    let event_processor = Self::parse_send_statement(&mut token_iterator, &variable_map)?;
+                    let event_processor =
+                        Self::parse_send_statement(&mut token_iterator, &variable_map)?;
                     event_processors.push(event_processor);
-                },
+                }
                 Token::Keyword(KeywordToken::Do) => {
                     let event_processor =
                         Self::parse_do_statement(&mut token_iterator, &variable_map)?;
@@ -154,7 +156,7 @@ impl Parser {
         })
     }
 
-    fn parse_store_statement(
+    fn parse_let_statement(
         token_iterator: &mut Iter<Token>,
         state_name: &mut String,
     ) -> Result<StateValue, ParserError> {
@@ -214,11 +216,13 @@ impl Parser {
 
         match_keyword_token!(token_iterator, KeywordToken::From);
 
-        let event_producer_address: u16 = match_variable_or_value!(token_iterator, variable_map).try_into()?;
+        let event_producer_address: u16 =
+            match_variable_or_value!(token_iterator, variable_map).try_into()?;
 
         match_keyword_token!(token_iterator, KeywordToken::To);
 
-        let receiver_address: u16 = match_variable_or_value!(token_iterator, variable_map).try_into()?;
+        let receiver_address: u16 =
+            match_variable_or_value!(token_iterator, variable_map).try_into()?;
 
         match_symbol_token!(token_iterator, SymbolToken::Semicolon);
 
@@ -232,14 +236,13 @@ impl Parser {
                 filter: Box::new(U16IsEqualFilter::new(event_producer_address)),
             },
         ];
-        let extractor: Box<dyn Extractor> = Box::new(PacketExtractor::new());
-        let producer: Box<dyn Producer> = Box::new(PacketProducer::new(receiver_address));
 
-        Ok(EventProcessor {
-            matchers,
-            extractor,
-            producer,
-        })
+        let creators = vec![Creator {
+            extractor: Box::new(PacketExtractor::new()),
+            producer: Box::new(PacketProducer::new(receiver_address)),
+        }];
+
+        Ok(EventProcessor { matchers, creators })
     }
 
     fn parse_do_statement(
@@ -249,8 +252,7 @@ impl Parser {
         match_symbol_token!(token_iterator, SymbolToken::OpenBrace);
 
         let mut matchers = vec![];
-        let mut extractor: Box<dyn Extractor> = Box::new(NoneExtractor::new());
-        let mut producer: Box<dyn Producer> = Box::new(NoneProducer::new());
+        let mut creators = vec![];
 
         while let Some(token) = token_iterator.next() {
             match token {
@@ -259,20 +261,15 @@ impl Parser {
                     matchers.push(matcher);
                 }
                 Token::Keyword(KeywordToken::Fire) => {
-                    let result = Self::parse_fire_statement(token_iterator, variable_map)?;
-                    extractor = result.0;
-                    producer = result.1;
+                    let creator = Self::parse_fire_statement(token_iterator, variable_map)?;
+                    creators.push(creator);
                 }
                 Token::Symbol(SymbolToken::CloseBrace) => break,
                 _ => return Err(ParserError::UnexpectedToken(token.clone())),
             }
         }
 
-        Ok(EventProcessor {
-            matchers,
-            extractor,
-            producer,
-        })
+        Ok(EventProcessor { matchers, creators })
     }
 
     fn parse_match_statement(
@@ -284,16 +281,19 @@ impl Parser {
         match sub_token_iterator.next() {
             Some(Token::Keyword(KeywordToken::Event)) => {
                 match_keyword_token!(token_iterator, KeywordToken::Event);
-                return Self::parse_match_event_statement(token_iterator, variable_map)
-            },
+                return Self::parse_match_event_statement(token_iterator, variable_map);
+            }
             Some(Token::Keyword(KeywordToken::Producer)) => {
                 match_keyword_token!(token_iterator, KeywordToken::Producer);
-                return Self::parse_match_producer_statement(token_iterator, variable_map)
-            },
+                return Self::parse_match_producer_statement(token_iterator, variable_map);
+            }
+            Some(Token::Keyword(KeywordToken::Tick)) => {
+                match_keyword_token!(token_iterator, KeywordToken::Tick);
+                return Self::parse_match_tick_statement(token_iterator, variable_map);
+            }
             _ => (),
         }
 
-
         match_symbol_token!(token_iterator, SymbolToken::OpenBrace);
 
         let mut sub_token_iterator = token_iterator.clone();
@@ -354,10 +354,22 @@ impl Parser {
         Ok(Matcher { extractor, filter })
     }
 
+    fn parse_match_tick_statement(
+        token_iterator: &mut Iter<Token>,
+        _variable_map: &BTreeMap<String, Variable>,
+    ) -> Result<Matcher, ParserError> {
+        match_symbol_token!(token_iterator, SymbolToken::Semicolon);
+
+        let extractor = Box::new(EventCodeExtractor::new());
+        let filter = Box::new(U16IsEqualFilter::new(INTERNAL_SYSTEM_TICK_EVENT_CODE));
+
+        Ok(Matcher { extractor, filter })
+    }
+
     fn parse_fire_statement(
         token_iterator: &mut Iter<Token>,
         variable_map: &BTreeMap<String, Variable>,
-    ) -> Result<(Box<dyn Extractor>, Box<dyn Producer>), ParserError> {
+    ) -> Result<Creator, ParserError> {
         match_symbol_token!(token_iterator, SymbolToken::OpenBrace);
 
         let mut sub_token_iterator = token_iterator.clone();
@@ -387,7 +399,10 @@ impl Parser {
 
         let producer = Self::parse_producer(&mut sub_token_iterator, variable_map)?;
 
-        Ok((extractor, producer))
+        Ok(Creator {
+            extractor,
+            producer,
+        })
     }
 
     fn parse_extractor(
