@@ -1,5 +1,5 @@
-use regex_lexer::{Lexer, LexerBuilder};
 use parse_int::parse;
+use regex_lexer::{Lexer, LexerBuilder};
 
 #[derive(Debug, Clone)]
 pub enum Token {
@@ -11,7 +11,7 @@ pub enum Token {
 
 #[derive(Debug, Clone)]
 pub enum KeywordToken {
-    Store,
+    Let,
     Const,
     Send,
     From,
@@ -20,6 +20,7 @@ pub enum KeywordToken {
     Match,
     Event,
     Producer,
+    Tick,
     Fire,
 }
 
@@ -68,7 +69,7 @@ impl Tokenizer {
             .token(r"(_|[a-zA-Z])[a-zA-Z_0-9]*", |token| {
                 Some(Token::Text(String::from(token)))
             })
-            .token(r"store", |_| Some(Token::Keyword(KeywordToken::Store)))
+            .token(r"let", |_| Some(Token::Keyword(KeywordToken::Let)))
             .token(r"const", |_| Some(Token::Keyword(KeywordToken::Const)))
             .token(r"send", |_| Some(Token::Keyword(KeywordToken::Send)))
             .token(r"from", |_| Some(Token::Keyword(KeywordToken::From)))
@@ -76,7 +77,10 @@ impl Tokenizer {
             .token(r"do", |_| Some(Token::Keyword(KeywordToken::Do)))
             .token(r"match", |_| Some(Token::Keyword(KeywordToken::Match)))
             .token(r"event", |_| Some(Token::Keyword(KeywordToken::Event)))
-            .token(r"producer", |_| Some(Token::Keyword(KeywordToken::Producer)))
+            .token(r"producer", |_| {
+                Some(Token::Keyword(KeywordToken::Producer))
+            })
+            .token(r"tick", |_| Some(Token::Keyword(KeywordToken::Tick)))
             .token(r"fire", |_| Some(Token::Keyword(KeywordToken::Fire)))
             .token(r";", |_| Some(Token::Symbol(SymbolToken::Semicolon)))
             .token(r":", |_| Some(Token::Symbol(SymbolToken::Colon)))
